/*****************************************************************************

	Felix IRC client Add-ons architecture sample code

	This is the first API to use add-ons in Felix.
	This first release include global add-ons. They'll get everything
	everything received from the server or send to it.
	
	For both message (in and out) you must follow the BMessage rule :
	
	name		type			value
	"what"		B_INT32_TYPE	'Imsg'
	"IrcRaw"	B_STRING_TYPE	Your irc string

revision : 10/02/97

Modification :
	- in order to have prefs for each addon, the addon must create a BView.
	  the view must be 233x228 and support its own BMessages.
	  The view won't be resized.
	  The addon must manage itself to save the data in a file.
	  the file path must be "[B_USER_SETTINGS_DIRECTORY]/Felix/"
	- New init function. It return the BView. This function is the same for all
	  AddOns (global, action and dcc).
	  The BView can be NULL. In that case, a default view will be created.
	- In the former version, each server has its own image of the add on. Now, there is
	  only one image for all the servers. They just call a function to get a looper.
	  Thus, all the loopers can share datas (thru global vars), or there can be only
	  one looper for all the server (as in URL-SA);
	  
	  IF YOU USE THE SAME LOOPER FOR N SERVERS IT WILL RECEIVE A B_QUIT_REQUESTED EACH TIME
	  YOU QUIT A SERVER. THUS YOU'LL HAVE TO IGNORE THEM AND QUIT YOUR BLOOPER FROM
	  AddOnTerminate(void).

	For more information : ducrohet@club-internet.fr


*****************************************************************************/

#include "LogLooper.h"
#include "PrefView.h"

// global data.
bool enable_log;	// is the logging enabled ?
BDirectory log_f;  // directory of the log files.

#pragma export on
extern "C" BView * AddOnInit(void);
extern "C" void AddOnTerminate(void);
extern "C" BLooper * CreateLooper(const char *name, BLooper *ltsm);
#pragma export reset

void read_prefs_file(void);
void write_prefs_file(void);

BView * AddOnInit(void) {
	enable_log = true;

// read the prefs file
	read_prefs_file();

	// Get app folder
	app_info info;
	be_app->GetAppInfo(&info);
	BEntry entry(&info.ref);
	BDirectory app_f;
	entry.GetParent(&app_f);

	BEntry d_entry;
	if (app_f.FindEntry("logs",&d_entry) == 0) {
		// folder exists.
		log_f.SetTo(&d_entry);
	}
	else {
		// folder doesn't exist.
		// we create the folder
		app_f.CreateDirectory("logs",&log_f);
	}

	// create the view for the preferences.
	BView *view = new PrefView (BRect(0,0,233,228),"test", B_FOLLOW_NONE,B_WILL_DRAW);
	return view;
}

BLooper * CreateLooper(const char *name, BLooper *ltsm) {
	// create the looper to which Felix will send the incoming message.
	// ltsm is the looper to which the add-on can send IRC message (in raw format)
	// name is the name of the server if you need it.
	if (enable_log)
		return new LogLooper(name,ltsm);
	return NULL;
}


void AddOnTerminate(void) {
	write_prefs_file();
}


void read_prefs_file(void) {
	// get the file path
	BPath path;
	find_directory(B_USER_SETTINGS_DIRECTORY,&path,true);
	path.Append("Felix");
	BEntry dir(path.Path());
	
	if (!dir.Exists()) {
		if (create_directory(path.Path(),0777)!=B_OK) {
			BAlert *alert = new BAlert("","Unable to create directory to save settings","Close");
			alert->Go();
			return;
		}
	}

	path.Append("log_settings");

	BFile file;

	if (file.SetTo(path.Path(),B_READ_ONLY)==B_NO_ERROR) {
		char en;
		file.Read(&en, 1);
		enable_log = (en=='1');
	}
}


void write_prefs_file(void) {
	// get the file path
	BPath path;
	find_directory(B_USER_SETTINGS_DIRECTORY,&path,true);
	path.Append("Felix");
	BEntry dir(path.Path());
	
	if (!dir.Exists()) {
		if (create_directory(path.Path(),0777)!=B_OK) {
			BAlert *alert = new BAlert("","Unable to create directory to save log settings","Close");
			alert->Go();
			return;
		}
	}

	path.Append("log_settings");

	BFile file;

	if (file.SetTo(path.Path(),B_WRITE_ONLY|B_CREATE_FILE)== B_NO_ERROR) {
		char en = (enable_log?'1':'0');
		file.Write(&en, 1);
	}
	else {
		BAlert *alert = new BAlert("","Unable to create file to save log settings","Close");
		alert->Go();
		return;
	}
}


